<script setup>
import JetModal from '@/Jetstream/Modal.vue';
import Highcharts from 'highcharts';
import VueMultiselect from 'vue-multiselect';
import { Link } from '@inertiajs/inertia-vue3';
import DK_Input from '@/components/dk_Input.vue';
import Notification from '@/components/dk_Notification2.vue';
import Button from '@/components/dk_Button.vue';
import Registers from '@/components/dk_Registers.vue';
import Datepicker from '@vuepic/vue-datepicker';
import '@vuepic/vue-datepicker/dist/main.css';
import { startOfDay, endOfDay, subDays, endOfMonth, endOfYear, startOfMonth, startOfYear, subMonths } from 'date-fns';
import { axiosApiCalls } from '../../../public/libs/datakorumJS';

let AppLayout;

if (window.location.origin.indexOf('localhost:8000') !== -1 || window.location.origin.indexOf('water.baltoro.app') !== -1) {
    AppLayout = require('@/Layouts/AppLayoutWater.vue').default;
} else {
    AppLayout = require('@/Layouts/AppLayoutCity.vue').default;
}

</script>

<style>

table.dataTable thead th,
table.dataTable thead td {
    padding: 5px 10px;
    font-size: 0.9rem !important;
    border-bottom: 1px solid rgba(200, 200, 200, 0.75) !important;
}

.dataTables_wrapper .dataTables_paginate .paginate_button.disabled,
.dataTables_wrapper .dataTables_paginate .paginate_button.disabled:hover,
.dataTables_wrapper .dataTables_paginate .paginate_button.disabled:active {
    cursor: default;
    color: rgba(200, 200, 200, 0.9) !important;
    border: 1px solid transparent;
    background: transparent;
    box-shadow: none;
}

.dataTables_wrapper .dataTables_paginate .paginate_button {
    box-sizing: border-box;
    display: inline-block;
    min-width: 1.5em;
    padding: 0.5em 1em;
    margin-left: 2px;
    text-align: center;
    text-decoration: none !important;
    cursor: pointer;
    cursor: hand;
    color: rgba(200, 200, 200, 0.9) !important;
    border: 0;
    border-radius: 0.375rem;
}

.dataTables_wrapper .dataTables_paginate .paginate_button:hover {
    color: rgba(200, 200, 200, 1) !important;
    background-color: rgba(0, 152, 219, 0.1) !important;
    background-image: unset !important;
    border: 0;
}

.dp__action_row {
    border-radius: 0.5rem;
}
.dp__input_reg {
    background: none;
    border-width: 1px;
    border-color: rgba(200, 200, 200, 0.9);
    border-radius: 0.5rem;
}
.dp__pointer {
    padding-top: 0.25rem;
    padding-bottom: 0.25rem;
}
.dp__theme_light {
    --dp-background-color: rgba(0, 57, 93, 0.95);
    --dp-text-color: #e3e3e3;
    --dp-hover-color: rgba(0, 255, 255, 0.2);
    --dp-hover-text-color: #FFFAFA;
    --dp-hover-icon-color: #e3e3e3;
    --dp-primary-color: rgba(0, 255, 255, 0.5);
    --dp-primary-text-color: #FFFAFA;
    --dp-secondary-color: #959595;
    --dp-border-color: #FFFAFA;
    --dp-menu-border-color: #FFFAFA;
    --dp-border-color-hover: #FFFAFA;
    --dp-disabled-color: #959595;
    --dp-scroll-bar-background: #f3f3f3;
    --dp-scroll-bar-color: #959595;
    --dp-success-color: rgba(5, 255, 243, 0.7);
    --dp-success-color-disabled: rgba(5, 255, 243, 0.7);
    --dp-icon-color: #e3e3e3;
    --dp-danger-color: #e6002e;
    --dp-highlight-color: rgba(25, 118, 210, 0.1);
}
</style>

<template>
    <AppLayout title="Dashboard">

        <div style="height: calc(100vh - 4.75rem);" class="bg-darkblue-background -z-1 overflow-y-scroll cursor-default select-none">
            <div class="mx-6 mt-2 text-xs text-center text-gray-light font-light flex justify-between">
                <div class="grid place-content-center justify-start justify-items-start gap-2">
                    <div class="inline-flex justify-center items-center">
                        <p class="text-white-snow text-2xl w-full text-left">{{ this.data.device.name }}&nbsp;(Id:&nbsp;{{ this.data.device.id }})</p>
                    </div>
                    <Datepicker id="interval_date" class="min-w-[21rem]" v-model="date" vertical
                            :presetRanges="this.presetRanges" range @update:modelValue="methodUpdateDate" :clearable="false"
                            :format="this.methodFormatDatetoDatepicker"></Datepicker>
                </div>

                <div class="grid justify-items-stretch">
                    <div class="flex justify-start items-end">
                        <div class="flex gap-2">
                            <Registers
                                :device="this.data.device"
                                :user="this.user"
                            />

                            <Link onclick="window.emitter.emit('changeLoaderStatus', true, 'orbit')" :href="route('cityReadings', { idDevice: this.data.device.id })">
                                <Button color="blue" :fixedSize="true">
                                    {{ this.$t("general.Readings") }}
                                </Button>
                            </Link>

                            <Button color="blue" :fixedSize="true" onclick="window.emitter.emit('changeLoaderStatus', true, 'orbit'); window.history.go(-1)">
                                {{ this.$t("general.Back") }}
                            </Button>
                        </div>
                    </div>
                </div>
            </div>

            <div class="w-full h-fit px-6 py-4">
                <div class="w-full baltoro-container-nr !bg-darkblue-background rounded-lg gap-4">

                    <div class="w-full flex flex-row items-center justify-between py-2 pl-4 pr-2 rounded-t-lg"
                        :class="['!bg-gradient-to-r from-' + this.getUnitColorState()]">

                        <p class="text-2xl text-left text-white-snow font-normal whitespace-nowrap"> Unidad Optidrive </p>

                        <div class="flex flex-row gap-2 text-white-snow">

                            <div v-if="this.getUnitBitState(0)" class="rounded-md px-2 py-1"
                                :class="{
                                    'border border-gray-medium': true,
                                    'bg-success-start': false
                                }"
                            >
                                Marcha
                            </div>
                            <div v-else class="rounded-md px-2 py-1"
                                :class="{
                                    'border border-gray-medium': this.getUnitColorState() !== 'gray-semimedium',
                                    'bg-gray-semimedium': this.getUnitColorState() === 'gray-semimedium'
                                }"
                            >
                                Detenido
                            </div>

                            <div v-if="this.getUnitBitState(1)" class="rounded-md px-2 py-1"
                                :class="{
                                    'border border-gray-medium': this.getUnitColorState() !== 'alert-start',
                                    'bg-alert-start': this.getUnitColorState() === 'alert-start'
                                }"
                            >
                                Unidad Disparada
                            </div>
                            <div v-else class="rounded-md px-2 py-1"
                                :class="{
                                    'border border-gray-medium': true,
                                    'bg-success-start': false
                                }"
                            >
                                Unidad Sana
                            </div>

                            <div v-if="this.getUnitBitState(2)" class="rounded-md px-2 py-1"
                                :class="{
                                    'border border-gray-medium': this.getUnitColorState() !== 'success-start',
                                    'bg-success-start': this.getUnitColorState() === 'success-start'
                                }"
                            >
                                Manual
                            </div>
                            <div v-else class="rounded-md px-2 py-1"
                                :class="{
                                    'border border-gray-medium': this.getUnitColorState() !== 'info-start',
                                    'bg-info-start': this.getUnitColorState() === 'info-start'
                                }"
                            >
                                Automático
                            </div>

                            <div v-if="this.getUnitBitState(7)" class="rounded-md px-2 py-1"
                                :class="{
                                    'border border-gray-medium': this.getUnitColorState() !== 'warning-start',
                                    'bg-warning-start': this.getUnitColorState() === 'warning-start'
                                }"
                            >
                                Condición de carga Baja o Elevada
                            </div>
                            <div v-else class="rounded-md px-2 py-1"
                                :class="{
                                    'border border-gray-medium': true,
                                    'bg-success-start': false
                                }"
                            >
                                Condición Normal
                            </div>
                        </div>
                    </div>

                    <div class="w-full flex flex-row items-center justify-between pl-4 pr-2 py-1.5">

                        <div class="flex flex-row justify-center items-baseline gap-x-2 whitespace-nowrap h-fit rounded-md hover:bg-cyan-opa/20 px-2 py-0.5 cursor-pointer"
                            @click="openModal()">
                            <i v-if="getErrorMessage() === 'No hay Fallo'" class="fa-solid fa-circle-check" style="font-size:1rem; color:#10b981;"></i>
                            <p class="font-normal text-md text-gray-light flex whitespace-nowrap">
                                {{ getErrorMessage() }}
                            </p>
                        </div>

                        <JetModal :show="this.boolModal" :closeable="false">

                            <div class="py-2 px-4 cursor-default flex flex-col justify-between max-w-[40rem] w-fit gap-1"  v-bind:class="{'w-fit' : this.screen_width >= 768, 'w-[90vw]' : this.screen_width < 768}">

                                <p class="font-semibold text-center text-cyan-text text-2xl leading-7"> Alertas </p>

                                <div class="w-fit max-w-[35rem] max-h-[60vh] text-pretty leading-5 text-base overflow-y-scroll">
                                    <ol class="flex flex-col gap-0.5 pr-0.5">
                                        <li v-for="code in this.errorCodes" :key="code" @click="switchAlert(code)"
                                            class="rounded-md hover:bg-cyan-opa/20 px-2 py-0.5 flex flex-row gap-2">
                                            <i v-if="this.selectedAlert == code" class="fa-solid fa-caret-down fa-xs pt-2.5"/>
                                            <i v-else class="fa-solid fa-caret-right fa-xs pt-2.5"/>
                                            <div class="flex flex-col w-full gap-1">
                                                {{ getErrorMessage(code) }}
                                                <div v-if="this.selectedAlert == code" class="w-full border-b border-gray-medium text-gray-light pb-1 leading-4 text-sm">
                                                    {{ getErrorAction(code) }}
                                                </div>
                                            </div>
                                        </li>
                                    </ol>
                                </div>

                                <div class="flex pt-2 font-light text-gray-light text-center justify-end">
                                    <Button color="blue" :fixedSize="true" @click="this.boolModal = false" >
                                        {{ this.$t("general.Close") }}
                                    </Button>
                                </div>
                            </div>
                        </JetModal>

                        <div class="flex flex-row gap-1.5 text-white-snow text-sm">

                            <div class="rounded-full px-2.5 py-0.5 bg-cyan-opa/40"
                                :class="{'border border-gray-medium/20 text-gray-medium/40 !bg-transparent': !this.getUnitBitState(3)}">
                                Inhibición
                            </div>

                            <div class="rounded-full px-2.5 py-0.5 bg-cyan-opa/40"
                                :class="{'border border-gray-medium/20 text-gray-medium/40 !bg-transparent': !this.getUnitBitState(4)}">
                                Servicio devido
                            </div>

                            <div class="rounded-full px-2.5 py-0.5 bg-cyan-opa/40"
                                :class="{'border border-gray-medium/20 text-gray-medium/40 !bg-transparent': !this.getUnitBitState(5)}">
                                En espera
                            </div>

                            <div class="rounded-full px-2.5 py-0.5 bg-cyan-opa/40"
                                :class="{'border border-gray-medium/20 text-gray-medium/40 !bg-transparent': !this.getUnitBitState(6)}">
                                Unidad Lista
                            </div>

                        </div>

                    </div>

                    <div class="w-full p-6">

                        <div class="w-full gap-6 grid grid-cols-6">

                            <div class="flex flex-col w-full justify-between items-start baltoro-container col-span-3">

                                <div class="flex flex-row w-full justify-between items-center p-4">
                                    <a class="text-base text-center text-gray-light font-normal whitespace-nowrap">{{ this.data.names[6] }}</a>

                                    <div class="h-fit flex flex-row items-center gap-2 w-[16rem]">
                                        <p class="text-gray-light text-base">{{ this.$t("general.Transducer") }}:</p>
                                        <VueMultiselect v-model="this.vmodel_transducer_AI2" placeholder=""
                                            :options="this.options_transducer" :close-on-select="true" :multiple="false"
                                            label="name" track-by="id" :allow-empty="false"
                                            @select="set_options_transducerAI2"/>
                                    </div>
                                </div>

                                <div class="w-full h-full p-6 min-h-[14rem]" id="id_chart_pressure_6"></div>
                            </div>


                            <div class="flex flex-col w-full justify-between items-start baltoro-container col-span-3">

                                <div class="flex flex-row w-full justify-between items-center p-4">
                                    <a class="text-base text-center text-gray-light font-normal whitespace-nowrap">{{ this.data.names[5] }}</a>

                                    <div class="h-fit flex flex-row items-center gap-2 w-[16rem]">
                                        <p class="text-gray-light text-base">{{ this.$t("general.Transducer") }}:</p>
                                        <VueMultiselect v-model="this.vmodel_transducer_AI1" placeholder=""
                                            :options="this.options_transducer" :close-on-select="true" :multiple="false"
                                            label="name" track-by="id" :allow-empty="false"
                                            @select="set_options_transducerAI1"/>
                                    </div>
                                </div>

                                <div class="w-full h-full p-6 min-h-[14rem]" id="id_chart_5"></div>
                            </div>

                            <div class="w-full grid grid-cols-6 col-span-6 h-full place-items-stretch gap-4 2xl:gap-x-12 pt-2 p-4 baltoro-container">

                                <div class="w-full flex flex-col justify-center items-center gap-1 p-2 border border-transparent rounded-md">
                                    <div class="w-full" id='id_chart_PID_6'></div>
                                    <div class="w-full" id='id_label_PID_6'></div>
                                    <p class="text-xs text-center text-gray-light font-normal whitespace-nowrap"> Valor Actual PID </p>
                                </div>

                                <div class="w-full flex flex-col justify-center items-center gap-1 p-2 border border-transparent rounded-md">
                                    <div class="w-full" id='id_chart_2'></div>
                                    <div class="w-full" id='id_label_2'></div>
                                    <p class="text-xs text-center text-gray-light font-normal whitespace-nowrap"> {{ this.data.names[2] }} </p>
                                </div>

                                <div class="w-full flex flex-col justify-center items-center gap-1 p-2 border border-transparent rounded-md">
                                    <div class="w-full" id='id_chart_3'></div>
                                    <div class="w-full" id='id_label_3'></div>
                                    <p class="text-xs text-center text-gray-light font-normal whitespace-nowrap"> {{ this.data.names[3] }} </p>
                                </div>

                                <div class="w-full flex flex-col justify-center items-center gap-1 p-2 border border-transparent rounded-md">
                                    <div class="max-w-[12rem] w-full h-full flex justify-center items-center" id='id_label_10'></div>
                                    <p class="text-xs text-center text-gray-light font-normal whitespace-nowrap"> {{ this.data.names[10] }} </p>
                                </div>

                                <div class="w-full flex flex-col justify-center items-center gap-1 p-2 border border-transparent rounded-md">
                                    <div class="max-w-[12rem] w-full h-full flex justify-center items-center" id='id_label_7'></div>
                                    <p class="text-xs text-center text-gray-light font-normal whitespace-nowrap"> {{ this.data.names[7] }} </p>
                                </div>

                                <div class="w-full flex flex-col justify-center items-center gap-1 p-2 border border-transparent rounded-md">
                                    <div class="max-w-[12rem] w-full h-full flex justify-center items-center" id='id_label_9'></div>
                                    <p class="text-xs text-center text-gray-light font-normal whitespace-nowrap"> {{ this.data.names[9] }} </p>
                                </div>

                                <div class="flex flex-col justify-center items-center col-span-2 col-start-3">
                                    <div class="w-full flex flex-col justify-center items-center gap-1 p-2 border border-transparent rounded-md">
                                        <div class="w-full h-full grid grid-cols-3 grid-rows-2 place-items-stretch gap-2 p-2 px-6">
                                            <div v-for="bit in 6" :key="bit" class="text-white-snow border border-gray-semimedium flex justify-center items-center rounded-md"
                                                :class="{'bg-cyan-opa/40': this.getDigitalInputBit(bit-1)}">
                                                DI{{bit}}
                                            </div>
                                        </div>
                                        <p class="text-xs text-center text-gray-light font-normal whitespace-nowrap"> {{ this.data.names[4] }} </p>
                                    </div>
                                </div>

                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>

    </AppLayout>
</template>

<script>
export default {
    props: ['data', 'user'],

    data() {
        return {
            Back: localStorage.getItem('Back'),
            screen_width: 0,

            date: undefined,

            selectedAlert: null,

            boolModal: false,
            errorCodes: [3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 29, 40, 41, 42, 43, 44, 45, 48, 49, 50, 52, 53, 54],

            selectedSensor: undefined,
            lastSelectedSensor: undefined,

            formatDate: (date, utc) => {
                date = new Date(date);
                // utc en 0 para formatear hora local del usuario, 1 para formatear UTC
                if (utc == 0) { date.setHours(date.getHours() + this.user.timezone_offset) }
                else if (utc == -1) { date.setHours(date.getHours() - this.user.timezone_offset) }
                return (
                    date.getFullYear() + "-" +
                    ((date.getMonth() + 1 + '').length < 2 ? "0" + (date.getMonth() + 1) : (date.getMonth() + 1)) + "-" +
                    ((date.getDate() + '').length < 2 ? "0" + date.getDate() : date.getDate()) + " " +
                    ((date.getHours() + '').length < 2 ? "0" + date.getHours() : date.getHours()) + ":" +
                    ((date.getMinutes() + '').length < 2 ? "0" + date.getMinutes() : date.getMinutes()) + ":" +
                    ((date.getSeconds() + '').length < 2 ? "0" + date.getSeconds() : date.getSeconds())
                );
            },

            presetRanges: [
                { label: this.$t("general." + "Today"), range: [startOfDay(new Date()), new Date()] },
                { label: this.$t("general." + "Yesterday"), range: [startOfDay(subDays(new Date(), 1)), endOfDay(subDays(new Date(), 1))] },
                { label: this.$t("general." + "Last 7 Days"), range: [new Date().setDate(new Date().getDate() - 7), new Date().setDate(new Date().getDate())] },
                { label: this.$t("general." + "Last 14 Days"), range: [new Date().setDate(new Date().getDate() - 14), new Date().setDate(new Date().getDate())] },
                { label: this.$t("general." + "Last 30 Days"), range: [new Date().setDate(new Date().getDate() - 30), new Date().setDate(new Date().getDate())] },
                { label: this.$t("general." + "This month"), range: [startOfMonth(new Date()), new Date()] },
                { label: this.$t("general." + "Last month"), range: [startOfMonth(subMonths(new Date(), 1)), endOfMonth(subMonths(new Date(), 1))] }
            ],

            //INITIAL STATES
            ini_transducerAI1: (this.data.transducerAI1 && this.data.transducerAI1 !== false) ? parseFloat(this.data.transducerAI1) : 0,
            ini_transducerAI2: (this.data.transducerAI2 && this.data.transducerAI2 !== false) ? parseFloat(this.data.transducerAI2) : 0,

            //OPTIONS
            options_transducer: undefined,

            //VMODELS
            vmodel_transducer: undefined,
            vmodel_transducer_AI1: undefined,
            vmodel_transducer_AI2: undefined,
        }
    },

    beforeCreate() {
        this.$i18n.locale = this.user.language
    },

    beforeMount() {
        this.screen_width = window.screen.width;

        this.options_transducer = [
            {
                id: 0,
                name: '0 → 10 (bar)',
                ratio: 0.10,
            },{
                id: 1,
                name: '0 → 15 (bar)',
                ratio: 0.15,
            },{
                id: 2,
                name: '0 → 16 (bar)',
                ratio: 0.16,
            },{
                id: 3,
                name: '0 → 20 (bar)',
                ratio: 0.20,
            },{
                id: 4,
                name: '0 → 25 (bar)',
                ratio: 0.25,
            },
        ];

        this.vmodel_transducer_AI1 = this.options_transducer[this.ini_transducerAI1];
        this.vmodel_transducer_AI2 = this.options_transducer[this.ini_transducerAI2];

        if (this.screen_width > 1280) {
        }
    },

    mounted() {

        let formatDate = this.formatDate

        this.Chart = {
            chart: {
                zoomType: 'x',
                backgroundColor: 'transparent',
                animation: {
                    duration: 150
                },
                resetZoomButton: {
                    position: {
                        align: 'left',
                        verticalAlign: 'top',
                        x: 0,
                        y: 2.5
                    },
                    theme: {
                        r: 5.6,
                    }
                }
            },
            accessibility: {
                enabled: false
            },
            title: {
                text: ''
            },
            xAxis: {
                visible: true,
                labels: {
                    style: {
                        color: 'rgba(200, 200, 200, 0.9)',
                        opacity: 0.7,
                    }
                },
                type: "datetime",
                dateTimeLabelFormats: {
                    week: '%m-%d',
                    month: '%Y-%m',
                    year: '%Y'
                },
                time: {
                    timezoneOffset: new Date().getTimezoneOffset(), // Configura la zona horaria actual
                    useUTC: true // Utiliza hora local
                }
            },
            yAxis: [{
                title: {
                text: ''
                },
                labels: {
                    formatter: function () {
                        return this.pos + '  ' + this.chart.userOptions.series[0].tooltip.valueSuffix
                    },
                    style: {
                        color: 'rgba(200, 200, 200, 0.9)',
                        opacity: 0.7,
                    }
                },
                //tickPositions: [0, 50, 100],
                visible: true,
            }],
            plotOptions: {
                column: {
                    borderWidth: 0
                }
            },
            exporting: {
                enabled: false
            },
            credits: {
                enabled: false
            },
            legend: {
                enabled: false,
            },

            tooltip: {
                shared: true,
                split: false,
                backgroundColor: 'rgba(7,82,103,0.95)',
                borderRadius: 12,
                borderWidth: 1,
                borderColor: 'rgba(250, 250, 250, 0.65)',
                padding: 6,
                formatter: function () {
                    var s = '<b>' + '<p style="font-size:12px; line-height: 12px; font-weight: 300; color:rgba(250, 250, 250, 0.95)">' + formatDate(this.x, -1) + '</p><br/>';
                    $.each(this.points, function () {
                        s += '<p style="font-size:12px; line-height: 12px; font-weight: 400; color:' + this.series.color + '">' + this.series.name + ' </p><p style="font-size:12px; line-height: 12px; font-weight: 400; color:' + this.series.color + '">' + this.y +
                            ' ' + this.series.userOptions.tooltip.valueSuffix + '</p><br/>';
                    });

                    return s;
                },
            },
        };

        this.Gauge = {
            chart: {
                type: 'gauge',
                backgroundColor: "transparent",
                plotBackgroundColor: null,
                plotBackgroundImage: null,
                plotBorderWidth: 0,
                plotShadow: false,
                spacing: [0, 0, 0, 0], // Ajusta los márgenes del gráfico según tus necesidades
                height: 90,
                marginTop: -5,
                marginBottom: -35,
            },
            title: null,
            pane: {
                startAngle: -110,
                endAngle: 110,
                background: {
                backgroundColor: "transparent",
                borderWidth: 0
                }
            },
            tooltip: {
                enabled: false
            },
            xAxis: {
                title: {
                text: "",
                style: {
                    color: "#FFFAFA",
                    fontSize: "12px",
                    fontWeight: "normal",
                    fontStyle: "normal"
                }
                },
                labels: {
                    rotation: -45,
                    style: {
                        color: 'white',
                        fontSize: '10px' // Ajusta el tamaño de la fuente de las etiquetas según tus necesidades
                    }
                }
            },
            plotOptions: {
                gauge: {
                    borderWidth: 0,
                    borderColor: "#05fff3", // Cambia el color del borde de la serie a #05fff3
                    dataLabels: {
                        enabled: false, // Desactiva las etiquetas con el dato y su unidad
                    },
                    pivot: {
                        radius: "4%",
                        backgroundColor: "#fff", // Cambia el color del pivote a blanco
                    },
                    dial: {
                        backgroundColor: "#fff", // Cambia el color de la flecha a blanco
                        radius: "70%", // Ajusta el tamaño de la flecha según tus necesidades
                        baseWidth: 3, // Ajusta el ancho de la base de la flecha según tus necesidades
                        topWidth: 1, // Ajusta el ancho de la punta de la flecha según tus necesidades
                        baseLength: "10%", // Ajusta la longitud de la base de la flecha según tus necesidades
                        rearLength: "-20%", // Ajusta la longitud de la punta de la flecha según tus necesidades
                    }
                },
            },
            credits: {
                enabled: false
            },
            exporting: {
                enabled: false,
            }
        };

        let export_title = this.data.device.name + '_' + this.data.device.id + '_' + this.data.dates[0]

        this.table = $('#basicTable').DataTable({
            language: {
                url: '/assets/i18n/' + this.user.language + '.json'
            },
            order: [[0, "desc"]],
            dom: '<"row"<"col-sm-6"B><"col-sm-6">>t<"row"<"col-sm-6"i><"col-sm-6"p>><"clear">',
            ordering: true,
            pageLength: 10,
            buttons: [
                {
                    extend: 'csv',
                    text: 'CSV',
                    title: export_title,
                    className: 'btn btn-brand',
                    exportOptions: {
                        columns: ':visible'
                    }
                },
                {
                    extend: 'excel',
                    text: 'Excel',
                    title: export_title,
                    className: 'btn btn-brand',
                    exportOptions: {
                        columns: ':visible'
                    }
                },
                {
                    extend: 'print',
                    text: 'Print',
                    title: export_title,
                    className: 'btn btn-brand',
                    exportOptions: {
                        columns: ':visible'
                    }
                },
            ]
        });

        this.date = [
            new Date(this.formatDate(this.data.dates[this.data.dates.length - 1], 1)),
            new Date(this.formatDate(this.data.dates[0], 1))
        ];

        window.emitter.emit('changeLoaderStatus', false, 'orbit')

        this.rechargePage(true);

    },

    methods: {

        rechargePage(force) {

            require('highcharts/highcharts-more')(Highcharts);

            for (let sensor in this.data.names) {

                let idComponent;
                let selector = false;

                if(parseInt(sensor) == this.selectedSensor){
                    selector = true;
                }

                if(selector || force){

                    switch(parseInt(sensor)){

                        case 2: // Frecuencia salida
                            idComponent = ['id_chart_2', 'id_label_2']
                            break;

                        case 3: // Corriente del motor
                            idComponent = ['id_chart_3', 'id_label_3']
                            break;

                        case 5: // Presion de entrada
                            idComponent = ['id_chart_5', 'id_label_5']
                            break;

                        case 6: // Presion de salida y valor actual del PID
                        //Se tienen que generar 2 tipos de gráficos
                            idComponent = ['id_chart_pressure_6', 'id_label_pressure_6', 'id_chart_PID_6', 'id_label_PID_6']
                            break;

                        case 7: // Temperatura Unidad
                            idComponent = ['id_label_7']
                            break;

                        // case 8: // Contador energía
                        //     idComponent = ['id_label_8']
                        //     break;

                        case 9: // Contador energía
                            idComponent = ['id_label_9']
                            break;

                        case 10: // Tiempo de ejecución
                            idComponent = ['id_label_10']
                            break;
                    }

                    if (sensor == 5 || sensor == 6) {

                        let Chart = this.Chart;

                        let highcharts_data = new Array(this.data.data[sensor].length);
                        let dates = new Array(this.data.data[sensor].length);
                        let units = this.data.units[sensor];
                        let name = this.data.names[sensor];
                        let data =  new Array(this.data.data[sensor].length);

                        this.data.data[sensor].forEach((measure, index) => {

                            dates[index] = new Date(
                                (this.data.dates[index] + " GMT")
                            ).getTime();

                            if (sensor == 6) {
                                data[index] = parseFloat((parseFloat(measure) * this.options_transducer[this.vmodel_transducer_AI2.id].ratio).toFixed(2));
                            } else {
                                data[index] = parseFloat((parseFloat(measure) * this.options_transducer[this.vmodel_transducer_AI1.id].ratio).toFixed(2));
                            }

                        });

                        data.forEach((measure, index) => {
                            highcharts_data[index] = [dates[index], parseFloat(measure)];
                        });

                        Chart.tooltip.valueSuffix = units;

                        Chart.series = [
                            {
                                name: name,
                                type: "spline",
                                data: highcharts_data.reverse(),
                                color: "#05fff3",
                                lineWidth: 1.5,
                                zIndex: 1,
                                marker: {
                                enabled: false,
                                },
                                tooltip: {
                                    valueSuffix: units,
                                },
                            },
                        ];

                        Highcharts.chart(idComponent[0], Chart);
                    }

                    if (sensor == 2 || sensor == 3 || sensor == 6) { // GAUGE
                        let min;
                        let max;
                        let data;

                        switch(parseInt(sensor)){

                            case 2:
                                min = 0;
                                max = 50;
                                data = this.data?.data?.[sensor][0] ?? 0;
                                break;
                            case 3:
                                min = 0;
                                max = 75;
                                data = this.data?.data?.[sensor][0] ?? 0;
                                break;
                            case 6:
                                min = 0;
                                max = 100;
                                data = this.data?.data?.[sensor][0] ? parseFloat((parseFloat(this.data?.data?.[sensor][0]) * this.options_transducer[this.vmodel_transducer_AI2.id].ratio).toFixed(2)) : 0;
                                break;

                            default:
                                min = 0;
                                max = 100;
                                data = this.data?.data?.[sensor][0] ?? 0;
                        }

                        this.Gauge.yAxis= {
                            min: min,
                            max: max,
                            tickPosition: 'outside',
                            lineColor: '#05fff3',
                            lineWidth: 1, // Ajusta el ancho de la línea del eje según tus necesidades
                            minorTickPosition: 'outside',
                            tickColor: '#05fff3',
                            minorTickColor: '#05fff3',
                            tickLength: 4, // Ajusta la longitud de las marcas del eje según tus necesidades
                            minorTickWidth: 1,
                            tickWidth: 1,
                            minorTickLength: 3, // Ajusta la longitud de las marcas menores del eje según tus necesidades
                            labels: {
                            distance: 6, // Ajusta la distancia de las etiquetas al eje según tus necesidades
                            rotation: 'auto',
                            style: {
                                color: '#05fff3',
                                fontSize: '10px' // Ajusta el tamaño de la fuente de las etiquetas según tus necesidades
                            }
                            },
                            tickPositions:
                            [
                                min,
                                min + (max-min)/4,
                                min + (max-min)/2,
                                min + 3*(max-min)/4,
                                max
                            ],
                            offset: -10,
                            endOnTick: false
                        },

                        this.Gauge.series = [{
                            name: '',
                            data: [{
                            y: data,
                            }],
                            tooltip: {
                            valueSuffix: ''
                            }
                        }]

                        var content =
                        '<div class="content-between cursor-default text-base w-full">' +
                            '<div class="text-center flex justify-center items-center w-full whitespace-nowrap gap-1 pl-6">' +
                                '<p class="text-2xl font-sevensegment text-white-snow">' + data + '</p>' +
                                '<p class="text-sm text-white-snow pb-0.5 self-end text-left w-6">' + this.data.units[sensor] + '</p>' +
                            '</div>' +
                        '</div>'

                        if(sensor == 6){
                            Highcharts.chart(idComponent[2], this.Gauge);
                            document.getElementById(idComponent[3]).innerHTML = content;
                        } else {
                            Highcharts.chart(idComponent[0], this.Gauge);
                            document.getElementById(idComponent[1]).innerHTML = content;
                        }

                    } else if(sensor == 7 || sensor == 10){ // BLOQUE

                        content =
                        '<div class="h-fit w-full grid place-items-center">' +
                            '<div class="px-4 w-full flex flex-col justify-center items-center rounded-lg border border-gray-medium gap-y-0.5 text-white-snow bg-darkblue-opa">' +
                                '<div class="w-full flex justify-between items-center py-2 px-0.5">' +
                                    '<div class="grid place-items-center h-full">' +
                                        '<i class="' + this.getIconName((this.data.units[sensor] != null ? this.data.units[sensor] : ''), this.data.names[sensor][0]) + '" style="font-size:1.5rem; color:rgba(225, 225, 225, 0.9);"></i>' +
                                    '</div>' +
                                    '<div class="flex gap-1 whitespace-nowrap text-lg">' +
                                        '<p class="text-4xl font-sevensegment text-white-snow">' + this.data?.data?.[sensor][0] + '</p>' +
                                        '<p class="text-md text-white-snow self-end text-left pb-[1px]">' + this.data.units[sensor] + '</p>' +
                                    '</div>' +
                                '</div>' +
                            '</div>' +
                        '</div>';

                        document.getElementById(idComponent[0]).innerHTML = content;

                    } else if(sensor == 9 ){ // BLOQUE DOBLE ENERGIA

                        content =
                        '<div class="h-fit w-full grid place-items-center">' +
                            '<div class="px-4 w-full flex flex-col justify-center items-center rounded-lg border border-gray-medium gap-y-0.5 text-white-snow bg-darkblue-opa">' +
                                '<div class="w-full flex justify-between items-center py-2 px-0.5">' +
                                    '<div class="grid place-items-center h-full">' +
                                        '<i class="' + this.getIconName((this.data.units[8] != null ? this.data.units[8] : ''), this.data.names[8][0]) + '" style="font-size:1.5rem; color:rgba(225, 225, 225, 0.9);"></i>' +
                                    '</div>' +

                                    '<div class="flex flex-col justify-center items-end gap-2">' +
                                        '<div class="flex gap-1 items-baseline whitespace-nowrap text-lg">' +
                                            '<p class="text-4xl font-sevensegment text-white-snow">' + this.data?.data?.[9][0] + '</p>' +
                                            '<p class="text-md text-white-snow self-end text-left">' + this.data.units[9] + '</p>' +
                                        '</div>' +
                                        '<div class="flex gap-1 items-baseline whitespace-nowrap text-sm">' +
                                            '<p class="text-xl font-sevensegment text-white-snow leading-3">' + this.data?.data?.[8][0] + '</p>' +
                                            '<p class="text-xs text-white-snow self-end text-left">' + this.data.units[8] + '</p>' +
                                        '</div>' +
                                    '</div>' +
                                '</div>' +
                            '</div>' +
                        '</div>';

                        document.getElementById(idComponent[0]).innerHTML = content;

                    }

                    // if (selector) {

                    //     let chartData = new Array();
                    //     let chartUnit = this.data.units[sensor];
                    //     let chartName = this.data.names[sensor];

                    //     if(sensor == 9){

                    //         this.data.epochMS.forEach( (date, index) => {
                    //             if(typeof this.data?.data?.[9][index] != 'undefined' && typeof this.data?.data?.[8][index] != 'undefined')
                    //                 chartData.push([date, this.data?.data?.[9][index] + (0.001 * this.data?.data?.[8][index])])
                    //         })

                    //     } else {
                    //         this.data.epochMS.forEach( (date, index) => {
                    //             if(typeof this.data?.data?.[sensor][index] != 'undefined')
                    //                 chartData.push([date, this.data?.data?.[sensor][index]])
                    //         })
                    //     }

                    //     this.Chart.yAxis = ({
                    //         id: 0,
                    //         opposite: true,
                    //         gridLineColor: '#647F8C',
                    //         title: {
                    //             text: ''
                    //         },
                    //         labels: {
                    //             formatter: function () {
                    //                 return this.pos + ' ' + chartUnit
                    //             },
                    //             style: {
                    //                 color: 'rgba(200, 200, 200, 0.9)',
                    //                 opacity: 0.7,
                    //             }
                    //         },
                    //         visible: true,
                    //     });

                    //     this.Chart.tooltip.valueSuffix = chartUnit;

                    //     this.Chart.series = [];

                    //     this.Chart.series.push({
                    //         name: chartName,
                    //         type: 'spline',
                    //         yAxis: 0,
                    //         data: chartData.reverse(),
                    //         color: "#05fff3",
                    //         lineWidth: 1.5,
                    //         zIndex: 1,
                    //         marker: {
                    //             enabled: false
                    //         },
                    //         tooltip: {
                    //             valueSuffix: chartUnit
                    //         }
                    //     });

                    //     Highcharts.chart('id_chart', this.Chart);

                    // }
                }
            }
        },

        getIconName(unit, input){

            let icon;

            switch(unit){
                case 'ºC': icon = 'fa-solid fa-temperature-half'; break;
                case 'h': icon = 'fa-solid fa-clock'; break;
                case 'kWh':
                case 'MWh': icon = 'fa-solid fa-bolt'; break;
            }

            if(icon == undefined){
                input = input.toString()
                icon = 'fa-solid fa-' + input.toLowerCase();
            }

            return icon;
        },

        methodUpdateDate(modelData) {

            if( modelData[0].getFullYear() === modelData[1].getFullYear() &&
                modelData[0].getMonth() === modelData[1].getMonth() &&
                modelData[0].getDate() === modelData[1].getDate()){

                    modelData[0].setHours(0);
                    modelData[0].setMinutes(0);
                    modelData[0].setSeconds(0);

                    modelData[1].setHours(23);
                    modelData[1].setMinutes(59);
                    modelData[1].setSeconds(59);
            }

            let date_start = this.formatDate(modelData[0], 1);
            let date_end = this.formatDate(modelData[1], 1);

            axiosApiCalls.methodGet('/gateway/values/period/'+this.user.id+'/'+this.data.device.id+'/'+date_start+'/'+date_end, this.user.token)
                .then((response) => {

                    if(!response?.dates){
                        window.emitter.emit(
                            'AppLayout_alert',
                            true,
                            this.$t('general.Gateway without records'),
                            this.$t('text.lacks records period'),
                            '18rem'
                        )
                    }

                    this.data.data = response.data;
                    this.data.dates = response.dates;
                    this.data.epochMS = response.epochMS;
                    this.selectedSensor = undefined

                    this.rechargePage(true)
                })
        },

        methodFormatDatetoDatepicker() {
            return generateDateDatepicker(this.date)
        },

        generateDateDatepicker(date) {

            var day1 = date[0].getDate();
            var month1 = date[0].getMonth() + 1;
            var year1 = date[0].getFullYear();
            var hour1 = date[0].getHours();
            var min1 = date[0].getMinutes();

            if(month1.toString().length == 1) month1 = '0' + month1;
            if(day1.toString().length == 1) day1 = '0' + day1;
            if(hour1.toString().length == 1) hour1 = '0' + hour1;
            if(min1.toString().length == 1) min1 = '0' + min1;

            var day2 = date[1].getDate();
            var month2 = date[1].getMonth() + 1;
            var year2 = date[1].getFullYear();
            var hour2 = date[1].getHours();
            var min2 = date[1].getMinutes();

            if(month2.toString().length == 1) month2 = '0' + month2;
            if(day2.toString().length == 1) day2 = '0' + day2;
            if(hour2.toString().length == 1) hour2 = '0' + hour2;
            if(min2.toString().length == 1) min2 = '0' + min2;

            return `${year1}/${month1}/${day1} ${hour1}:${min1} `+ this.$t("general.To") +` ${year2}/${month2}/${day2} ${hour2}:${min2}`;
        },

        mqtt_connection(iddevice) {

            var mqtt_topic = "/PUSHER/@P@" + this.user.idplatform + "/G@" + this.user.idgroup_selected + "/@D@" + iddevice;

            const mqtt = require('paho-mqtt');

            const mqtt_host = 'mqtt.datakorum.app';
            const mqtt_port = 8000;
            const mqtt_path = '';

            var userName = this.user.credentials.username;
            var password = this.user.credentials.password;

            var clientId = "APPclientid_" + parseInt(Math.random() * 100, 10);

            const client = new mqtt.Client(mqtt_host, mqtt_port, mqtt_path, clientId);

            client.connect({

            useSSL: true,
            mqttVersion: 4,
            userName: userName,
            password: password,

            onSuccess: () => {
                client.subscribe(mqtt_topic, {
                    onSuccess: () => {
                        console.log('éxito de suscripción ' + iddevice)
                    },
                    onFailure: () => {
                        console.error('fallo de suscripción ' + iddevice)
                    }
                });
            },

            onFailure: () => {
                console.error('fallo de conexión ' + iddevice)
            }

            });

            client.onConnectionLost = () => {
                console.error('perdida de conexión ' + iddevice)

                setTimeout(() => {
                    this.mqtt_connection(iddevice)
                }, 5000);

            };

            client.onMessageArrived = (message) => {

                var data = JSON.parse(JSON.parse(message.payloadString).frame_data);
                var when = this.formatDate(JSON.parse(message.payloadString).when * 1000);

                //this.rechargePage(true);

            };
        },

        capitalizeFirstLetter(string) {
            return string.charAt(0).toUpperCase() + string.slice(1);
        },

        getErrorMessage(code){

            let errorCode = parseInt(this.getFirstRegister(0), 2);

            if(typeof code !== 'undefined'){
                errorCode = code
            }

            switch (errorCode) {
                case 0: return 'No hay Fallo';
                case 3: return 'Disparo de sobrecorriente: Sobrecorriente instantánea en la salida de la unidad';
                case 4: return 'Disparo por sobrecarga: La unidad se ha disparado en sobrecarga tras suministrar >100 % del valor en P1-08 durante un período de tiempo';
                case 5: return 'Sobrecorriente del hardware: Sobrecorriente instantánea en la salida de la unidad';
                case 6: return 'Sobretensión en el bus CC';
                case 7: return 'Bajo tensión: Subtensión en el bus CC';
                case 8: return 'Disparo por Sobretemperatura en el disipador de calor';
                case 9: return 'Disparo por unidad debajo de la temperatura';
                case 10: return 'Cargar los parámetros por defecto';
                case 11: return 'Entrada digital Disparo externo';
                case 12: return 'Fallo en las comunicaciones serie de Optibus';
                case 13: return 'Excesiva ondulación de CC en el bus de CC interno';
                case 14: return 'Pérdida de fase de entrada';
                case 15: return 'Sobrecorriente instantánea en la salida de la unidad';
                case 16: return 'Fallo del termistor: Termistor defectuoso en el disipador de calor';
                case 17: return 'Error de datos del procesador de E/S: Fallo de la memoria interna';
                case 18: return 'Señal de 4-20mA fuera de rango: Señal perdida';
                case 19: return 'Error de datos del procesador de M/C: Fallo de la memoria interna';
                case 20: return 'Parámetro de usuario por defecto';
                case 21: return 'Sobrecalentamiento del PTC del motor';
                case 22: return 'Fallo del ventilador de refrigeración';
                case 23: return 'Temperatura ambiente demasiado alta';
                case 24: return 'Corriente del motor por encima del perfil configurado';
                case 25: return 'Corriente del motor por debajo del perfil configurado';
                case 26: return 'Fallo de la salida del convertidor';

                case 29: return 'Error en el circuito interno STO';

                case 40: return 'Fallo de autotune 1: Sintonización automática fallida';
                case 41: return 'Fallo de autotune 2: Sintonización automática fallida';
                case 42: return 'Fallo de autotune 3: Sintonización automática fallida';
                case 43: return 'Fallo de autotune 4: Sintonización automática fallida';
                case 44: return 'Fallo de autotune 5: Sintonización automática fallida';
                case 45: return 'Secuencia de fases de alimentación incorrecta';

                case 48: return 'Presión de retroalimentación baja, detectada por la función de llenado de la tubería';
                case 49: return 'Pérdida de fase de salida';
                case 50: return 'Fallo comunicaciones Modbus';

                case 52: return 'Fallo del módulo de opciones';
                case 53: return 'Fallo de comunicación de la tarjeta IO: comunicaciones de tarjeta ES';
                case 54: return 'Fallo de pérdida de comunicación BACnet';

                default: return 'Unknown Error Code';
            }
        },

        switchAlert(code){
            if(this.selectedAlert !== code){
                this.selectedAlert = code
            } else {
                this.selectedAlert = null
            }
        },

        getErrorAction(code){

            switch (code) {
                case 3: return 'El fallo se produce en la activación de la unidad. Compruebe el motor y el cable de conexión al motor en cuanto a cortocircuitos fase/fase y fase/tierra. Compruebe la carga mecánicamente ante una condición de atasco, bloqueo o estancamiento. Asegúrese de que los parámetros de la placa de identificación del motor estén introducidos correctamente: P1-07, P1-08, P1-09. Reduzca el ajuste de la tensión de refuerzo en P1-11. Incremente el tiempo de rampa ascendente en P1-03. Si el motor conectado posee un freno de retención, asegúrese de que el freno está conectado y controlado correctamente, y que se libera correctamente. El fallo ocurre durante la marcha Reduzca la ganancia del bucle de velocidad en P4-03 y P4-04.';
                case 4: return 'Compruebe para examinar si los puntos decimales están parpadeando (unidad en sobrecarga) e incremente la tasa de aceleración o reduzca la carga. Compruebe si la longitud del cable del motor se encuentra dentro del límite especificado para la unidad pertinente en la sección 11.5. Potencia y corriente de salida. Asegúrese de que los parámetros de la placa de identificación del motor están introducidos correctamente en P1-07, P1-08 y P1-09. Compruebe la carga mecánicamente para asegurarse de que esté libre y de que no se atasca o bloquea ni existen otros fallos mecánicos. En el caso de un ventilador centrífugo o una bomba, una pequeña reducción de la frecuencia de salida podría reducir significativamente la carga.';
                case 5: return 'Compruebe el cableado del motor y el propio motor para ver si hay cortocircuitos de fase a fase y de fase a tierra. Desconecte el motor y el cable del motor y repita el ensayo. Si la unidad se dispara sin ningún motor conectado, deberá reemplazarse, y comprobar y volver a ensayar el sistema completamente antes de que se instale una unidad de reemplazo.';
                case 6: return 'El valor de la tensión de bus CC puede visualizarse en P0-20. Un registro histórico se guarda a intervalos de 256 ms antes de un disparo en el parámetro P0-36. Este fallo está causado generalmente por un exceso de energía regenerativa que está siendo transferida desde la carga de vuelta a la unidad. Cuando está conectada una carga tipo inercia elevada o sobre arrastre. Si el fallo se produce en la parada o durante la deceleración, aumentar el tiempo de rampa de deceleración P1-04. Si está funcionando en control PID, asegúrese de que las rampas están activas reduciendo P3-11.';
                case 7: return 'Esto ocurre de manera rutinaria cuando se desconecta la alimentación. Si esto ocurre durante la marcha, compruebe la tensión de suministro entrante y todas las conexiones en la unidad, fusibles, contactores, etc.';
                case 8: return 'La temperatura del disipador de calor puede visualizarse en P0-21. Se almacena un registro histórico a intervalos de 30 segundos antes de un viaje en P0-38. Compruebe la temperatura ambiente de la unidad. Asegúrese de que el ventilador de refrigeración interno de la unidad está funcionando. Asegúrese de que el espacio necesario alrededor de la unidad es el indicado en el apartado 3.6. Directrices para el montaje de la carcasa (unidades IP20) mediante 3.10. Directrices para el montaje (unidades IP66) y no se ha restringido la trayectoria del flujo de aire de refrigeración hacia y desde la unidad. Reduzca el ajuste de la frecuencia de conmutación efectiva en el parámetro P2-24. Reduzca la carga en el motor/unidad.';
                case 9: return 'La desconexión se produce cuando la temperatura ambiente es inferior a -10 °C. La temperatura debe elevarse por encima de -10 °C para que la unidad se ponga en marcha.';
                case 10: return 'Pulse la tecla STOP, la unidad está lista ahora para configurarse para la aplicación requerida. Cuatro botones por defecto - ver sección 5.4. Cómo cambiar los parámetros.';
                case 11: return 'Disparo externo solicitado en los terminales de entrada de control. Algunos ajustes de P1-13 requieren un contacto normalmente cerrado para proporcionar un medio externo para disparar la unidad en el caso de que un dispositivo externo desarrolle un fallo. Si hay conectado un termistor del motor, compruebe si el motor está demasiado caliente.';
                case 12: return 'Comunicaciones perdidas con el PC o el teclado numérico remoto. Compruebe los cables y las conexiones a los dispositivos externos.';
                case 13: return 'El nivel de la tensión de ondulación del bus CC puede visualizarse en el parámetro P0-16. Un registro histórico se guarda a intervalos de 20 ms antes de un disparo en el parámetro P0-37. Compruebe que todas las fases trifásicas de suministro están presentes y dentro del 3 % de tolerancia de desequilibrio del nivel de tensión de suministro. Reduzca la carga del motor. Si el fallo persiste, póngase en contacto con su socio comercial de Invertek Drives.';
                case 14: return 'Unidad prevista para el uso con un suministro trifásico, una fase de entrada ha sido desconectada o se ha perdido.';
                case 15: return 'El fallo se produce en la activación de la unidad Compruebe el motor y el cable de conexión al motor en cuanto a cortocircuitos fase/fase y fase/tierra. Compruebe la carga mecánicamente ante una condición de atasco, bloqueo o estancamiento. Asegúrese de que los parámetros de la placa de identificación del motor estén introducidos correctamente: P1-07, P1-08, P1-09. Reduzca el ajuste de la tensión de refuerzo en P1-11. Incremente el tiempo de rampa ascendente en P1-03. Si el motor conectado posee un freno de retención, asegúrese de que el freno está conectado y controlado correctamente, y que se libera correctamente. El fallo ocurre durante la marcha Reduzca la ganancia del bucle de velocidad en P4-03 y P4-04.';
                case 16: return 'Remítase a su socio comercial de Invertek.';
                case 17: return 'Parámetros no guardados, valores por defecto recargados. Si el problema se repite, consulte a su distribuidor autorizado de IDL.';
                case 18: return 'La señal de referencia en la entrada analógica 1 ó 2 (terminales 6 ó 10) ha caído por debajo del umbral mínimo de 3mA cuando el formato de la señal está ajustado a 4-20mA. Compruebe la fuente de señal y el cableado hasta los terminales Optidrive.';
                case 19: return 'Los parámetros no se guardan, se recargan los valores de fábrica. Si el problema se repite, consulte a su distribuidor autorizado de IDL.';
                case 20: return 'Se ha cargado el parámetro de usuario por defecto. Pulse la tecla Stop. Tres botones por defecto - remítase a la sección 5.5. Restablecimiento de fábrica de los parámetros/restablecimiento por el usuario.';
                case 21: return 'El dispositivo PTC del motor conectado ha provocado la desconexión del accionamiento (entrada analógica 2 configurada para el dispositivo PTC).';
                case 22: return 'Compruebe y sustituya, en caso necesario, el ventilador de refrigeración interno de la unidad.';
                case 23: return 'Asegúrese de que el ventilador de refrigeración interno de la unidad está funcionando. Asegúrese de que el espacio necesario alrededor de la unidad es el indicado en las secciones 3.6. Directrices para el montaje de la carcasa (unidades IP20) mediante 3.10. Directrices para el montaje (unidades IP66) y no se ha restringido la trayectoria del flujo de aire de refrigeración hacia y desde la unidad. Incremente el flujo de aire de refrigeración hasta la unidad. Reduzca el ajuste de la frecuencia de conmutación efectiva en el parámetro P2-24. Reduzca la carga en el motor/unidad.';
                case 24: return 'La función de monitorización de corriente ha detectado niveles de corriente del motor por encima de la condición de funcionamiento normal para la aplicación. Compruebe que la carga mecánica no ha cambiado y que la carga no se ha atascado o calado. Para la aplicación de la bomba, compruebe si hay un posible bloqueo de la misma. Para las aplicaciones con ventilador, compruebe que el flujo de aire hacia y desde el ventilador no está restringido.';
                case 25: return 'La función de monitorización de corriente ha detectado niveles de corriente del motor por debajo de la condición de funcionamiento normal para la aplicación. Compruebe si hay roturas mecánicas que provoquen la pérdida de carga (por ejemplo, rotura de la correa). Compruebe que el motor no se ha desconectado de la unidad.';
                case 26: return 'Fallo en la salida de la unidad. Compruebe si los cables del motor están sueltos en la unidad y en el motor o en cualquier terminación intermedia. En caso contrario, consulte a su distribuidor autorizado de IDL.';

                case 29: return 'Remítase a su socio comercial de Invertek';

                case 40: return 'La resistencia del estator del motor medida varía entre las fases. Asegúrese de que el motor está correctamente conectado y libre de fallos. Compruebe la resistencia y el equilibrio correctos de los bobinados.';
                case 41: return 'La resistencia del estator del motor medida es demasiado grande. Asegúrese de que el motor está correctamente conectado y libre de fallos. Compruebe que el índice de potencia se corresponde con el índice de potencia de la unidad conectada.';
                case 42: return 'La inductancia medida del motor es demasiado baja. Asegúrese de que el motor está correctamente conectado y libre de fallos.';
                case 43: return 'La inductancia medida del motor es demasiado grande. Asegúrese de que el motor está correctamente conectado y libre de fallos. Compruebe que el índice de potencia se corresponde con el índice de potencia de la unidad conectada.';
                case 44: return 'Los parámetros medidos del motor no son convergentes. Asegúrese de que el motor está correctamente conectado y libre de fallos. Compruebe que el índice de potencia se corresponde con el índice de potencia de la unidad conectada.';
                case 45: return 'Se aplica únicamente a las unidades con tamaño de marco 8, indica que la secuencia de fase de suministro de la potencia entrante es incorrecta. Alguna de las 2 fases puede ser permutada.';

                case 48: return 'Compruebe que el sistema de bombeo no tiene fugas ni tuberías rotas. Compruebe que la función de llenado de tubos se ha puesto en marcha correctamente (P3-16 y P3-17).';
                case 49: return 'Una de las fases de salida del motor no está conectada a la unidad.';
                case 50: return 'Cuando se utiliza Modbus RTU: No se ha recibido un telegrama válido Modbus dentro del límite de tiempo de control establecido en P5-05. Compruebe que el maestro de red/PLC sigue funcionando. Compruebe los cables de conexión. Incremente el valor de P5-05 a un nivel adecuado. Cuando se utiliza una interfaz de bus de campo opcional: Se ha perdido la comunicación interna con el módulo opcional de comunicaciones insertado. Compruebe que el módulo se encuentra correctamente insertado.';

                case 52: return 'No se ha recibido un telegrama que contenga una palabra de control válida del maestro de la red dentro del límite de tiempo del perro guardián establecido en P5-05. Compruebe que el maestro de red/PLC sigue funcionando. Compruebe los cables de conexión. Incremente el valor de P5-05 a un nivel adecuado.';
                case 53: return 'Se ha perdido la comunicación interna con el módulo opcional de E/S insertado.';
                case 54: return 'No se ha recibido un telegrama válido BACnet dentro del límite de tiempo de control establecido en P5-05. Compruebe que el maestro de red/PLC sigue funcionando. Compruebe los cables de conexión. Incremente el valor de P5-05 a un nivel adecuado.';
                default: return '';
            }
        },

        openModal(){
            this.selectedAlert = parseInt(this.getFirstRegister(0), 2);
            this.boolModal = true
        },

        getUnitBitState(bit){
            if(this.getFirstRegister(1)){
                const register = this.getFirstRegister(1).split('').map(char => char === '1').reverse()

                if(bit !== undefined){
                    return register[bit];
                } else {
                    return register;
                }
            }

            return null;
        },

        getUnitColorState(){

            let color = ''

            if(this.getUnitBitState(1)){ // UNIDAD DISPARADA
                color = 'alert-start'
            } else if(this.getUnitBitState(7)){ // CONDICIÓN DE CARGA BAJA O ELEVADA
                color = 'warning-start'
            } else if(!this.getUnitBitState(0)){ // DETENIDA
                color = 'gray-semimedium'
            } else if(!this.getUnitBitState(2)){ // AUTOMÁTICA
                color = 'info-start'
            } else { // MANUAL
                color = 'success-start'
            }

            return color
        },

        getFirstRegister(input){

            if(this.data?.data?.[1]){
                const register = this.data.data[1][0].toString().padStart(16, '0');

                if(input === 0){ // BYTE SUPERIOR
                    return register.substring(0, 8)
                } else if(input === 1){ // BYTE INFERIOR
                    return register.substring(8, 16)
                }
            }

            return null
        },

        getDigitalInputBit(bit){

            if(this.data?.data?.[4]){
                const register = this.data?.data?.[4][0].toString().padStart(16, '0').split('').map(char => char === '1').reverse();

                if(bit !== undefined){
                    return register[bit];
                } else {
                    return register;
                }
            }

            return null
        },

        setSensor(sensor){
            if(this.selectedSensor != sensor) {
                this.selectedSensor = sensor
            } else {
                this.selectedSensor = undefined
            }

            setTimeout(() => {
                this.rechargePage()
            }, 0);
        },

        set_options_transducerAI1: function (item){

            this.vmodel_transducer = item

            let data = {transducerAI1: item.id};

            axiosApiCalls.methodPut('/gateway/edit_descriptors/'+this.user.id+'/'+this.data.device.id, this.user.token, data)
            .then((response) => {
                return response;
            })

            setTimeout(() => {
                this.rechargePage(true);
            }, 0);
        },

        set_options_transducerAI2: function (item){

            this.vmodel_transducer = item

            let data = {transducerAI2: item.id};

            axiosApiCalls.methodPut('/gateway/edit_descriptors/'+this.user.id+'/'+this.data.device.id, this.user.token, data)
            .then((response) => {
                return response;
            })

            setTimeout(() => {
                this.rechargePage(true);
            }, 0);
        }
    },
}
</script>
